@@ -39,7 +39,7 @@
 #'
 #' @param fast Select if you want the data to aggregated resulting in a faster, but perhaps more imprecise run, in Hz. Default is `50` (`numeric`)
 #'
-#' @param raw_data Select `TRUE` if the data is raw and cyclic mean should be calculated. **NB:** this function have not been validated, why validated methods for calculating cyclic mean are preferred. Default is `FALSE` (`boolian`)
+#' @param raw_data Select `TRUE` if the data is raw and cyclic mean should be calculated. **NB:** this function have not been validated, why validated methods for calculating cyclic mean are preferred. Only 1 period can be analysed using raw_data. Default is `FALSE` (`boolian`)
 #'
 #' @param interpolation Select the number of beats which should be interpolated. Default is up to `3` beats and `0` results in no interpolation. (`numeric`)
 #'
@@ -214,16 +214,18 @@ TFA <- function(
    if(output != "raw"){
       for(i in unique(df$period)){
          df_i <- df[df$period == i,]
-         result <- Z.TFA_func(df_i[,c("abp","mcav")], freq, output, vlf, lf, hf,
+         temp_result <- Z.TFA_func(df_i[,c("abp","mcav")], freq, output, vlf, lf, hf,
                                 detrend, spectral_smoothing, coherence2_thresholds,
                                 apply_coherence2_threshold, remove_negative_phase,
                                 remove_negative_phase_f_cutoff, normalize_ABP, normalize_CBFV,
                                 window_type, window_length, overlap, overlap_adjust, na_as_mean)
-         result <- as.data.frame(cbind(i,result))
-         colnames(result)[1] <- "period"
+         temp_result <- as.data.frame(cbind(i,temp_result))
+         colnames(temp_result)[1] <- "period"
+         result <- rbind(result,temp_result)
       }
+
    }else{
-      result <- Z.TFA_func(df_i[,c("abp","mcav")], freq, output, vlf, lf, hf,
+      result <- Z.TFA_func(df[,c("abp","mcav")], freq, output, vlf, lf, hf,
                            detrend, spectral_smoothing, coherence2_thresholds,
                            apply_coherence2_threshold, remove_negative_phase,
                            remove_negative_phase_f_cutoff, normalize_ABP, normalize_CBFV,
